@@ -4,7 +4,9 @@ import hashlib
 import hmac
 import json
 import logging
+import os
 import re
+import sys
 import urllib.parse
 from dataclasses import InitVar, dataclass, field
 from pathlib import Path
@@ -33,7 +35,7 @@ DEFAULT_VERSION = datetime.date.today().strftime("%Y-%m-%d")
 DEFAULT_HOST = "outscale.com"
 
 METHODS_SUPPORTED = {"GET", "POST"}
-SDK_VERSION = "1.8.0"
+SDK_VERSION = "1.9.0"
 SSL_VERIFY = True
 SUCCESS_CODES = {200, 201, 202, 203, 204}
 USER_AGENT = "osc_sdk " + SDK_VERSION
@@ -56,6 +58,7 @@ NO_AUTH_CALLS: Dict[str, Set[str]] = {
         "ReadVmTypes",
         "ResetAccountPassword",
         "SendResetPasswordEmail",
+        "ReadPublicCatalog",
     },
     "icu": {
         "AuthenticateAccount",
@@ -70,6 +73,9 @@ NO_AUTH_CALLS: Dict[str, Set[str]] = {
     },
 }
 
+dir_path = os.path.join(os.path.dirname(__file__))
+BASH_COMPLETION_PATH = os.path.abspath("{}/osc-cli-completion.bash".format(dir_path))
+
 
 class Configuration(TypedDict):
     method: str
@@ -84,6 +90,19 @@ class Configuration(TypedDict):
     host: str
 
 
+DEFAULT_CONF = cast(
+    Configuration,
+    {
+        "method": "POST",
+        "https": True,
+        "region_name": DEFAULT_REGION,
+        "ssl_verify": True,
+        "version": DEFAULT_VERSION,
+        "host": DEFAULT_HOST,
+    },
+)
+
+
 class PasswordParams(TypedDict, total=False):
     AuthenticationMethod: str
     Login: Optional[str]
@@ -567,7 +586,10 @@ class IcuCall(JsonApiCall):
             raise RuntimeError("Parameters lists are not supported")
 
         # Specific to ICU
-        if self.authentication_method == "accesskey":
+        if (
+            self.authentication_method == "accesskey"
+            or self.authentication_method == None
+        ):
             data.update({"AuthenticationMethod": "accesskey"})
 
         filters = self.get_filters(data)
@@ -688,7 +710,7 @@ def get_conf(profile: str) -> Configuration:
     conf_path = next((path for path in CONF_PATHS if path.exists()), None)
 
     if not conf_path:
-        raise RuntimeError("No configuration file found in home folder")
+        return DEFAULT_CONF
 
     json_profiles = json.loads(conf_path.read_text())
     # convert region to region_name in json to fit Mapping
@@ -710,7 +732,7 @@ def get_conf(profile: str) -> Configuration:
     try:
         return conf[profile]
     except KeyError:
-        raise RuntimeError(f"Profile {profile} not found in configuration file")
+        return DEFAULT_CONF
 
 
 def call_need_auth(service: str, call: str) -> bool:
@@ -724,8 +746,10 @@ def api_connect(
     login: Optional[str] = None,
     password: Optional[str] = None,
     authentication_method: Optional[str] = None,
+    bash_completion: bool = False,
     **kwargs: CallParameters,
 ):
+
     calls = {
         "api": OSCCall,
         "directlink": DirectLinkCall,
@@ -745,6 +769,18 @@ def api_connect(
 
 
 def main():
+    argc = len(sys.argv)
+    argv = sys.argv
+
+    if argc > 1:
+        for i in range(1, argc):
+            a = argv[i]
+            if a == "--bash_completion":
+                f = open(BASH_COMPLETION_PATH, "r")
+                print(f.read())
+                sys.exit()
+                return 0
+
     logging.basicConfig(level=logging.ERROR)
     fire.Fire(api_connect)
 
